@@ -215,6 +215,8 @@ sub stats {
        count(*) filter (where state = 'finished') as finished_jobs,
        count(*) filter (where state = 'inactive'
          and delayed > now()) as delayed_jobs,
+       (select count(*) from minion_locks where expires > now())
+         as active_locks,
        count(distinct worker) filter (where state = 'active') as active_workers,
        (select case when is_called then last_value else 0 end
          from minion_jobs_id_seq) as enqueued_jobs,
@@ -854,6 +856,12 @@ These fields are currently available:
 
 Number of jobs in C<active> state.
 
+=item active_locks
+
+  active_locks => 100
+
+Number of active named locks.
+
 =item active_workers
 
   active_workers => 100
